function in_data = fem_input

% fem_input.m - input file for FEM analysis  

% 2-D flow problem. Two 3-node constant gradiant triangular elements 

% Control Data: [   nodes            % Total number of nodes
%                   numel            % Total number of elements
%                   nodaldof         % Max dof per node
%                   nodesperelement  % Max nodes per element
%                   numat            % Max mumber of materials
%                   ndimensions      % Number of space dimensions  ]

in_data.control = [4 2 1 3 2 2 ];

% Nodal Data: [ node# x1 x2 x3] 
in_data.ND = [   
   1   1   1;
   2   3   1;
   3   3   2;
   4   1   2];
   
% Material Property Data: [ 
%                      Element type for material no. 1
%                      Element parameter 1 (Hydraulic conductivity)
%                      Element parameter 2 (Element thickness)
%                      Element parameter 3 (Capacitance)
%                      Element parameter 4
%                      Element parameter 5
 in_data.mater = [21 1 1 1 0 0;
                   21 1 1 1 0 0];                   

% Element Association Data: [ element# materialtype# node1# node2# ....] 
in_data.EL = [  
   1   1   1   2   4;
   2   2   2   3   4]; 
   
% Nodal Constraint Data: [ node# x1_disp x2_disp.... etc ] 
% 1 = fixed displacement; 0 = non-fixed displacement
in_data.CON = [  
   1   1;
   2   1;
   3   1;
   4   1];

% Nodal Load Data: [node# x1_load x2_load..... etc] 
% Magnitude of prescribed load OR displacement
in_data.LOAD = [ 
   1   0;
   2   1;
   3   1;
   4   0];

 