function [ Kl,Cl,Ml ] = elmt22( local_data )
% elmt21: 2-D three-node (triangular) element with 1 dof per node 
% for 2nd order PDE in (x1,x2) and 1st order PDE in (x1,x2)
% (Constant gradient triangle, etc.)
%
%Element subroutine to construct local stiffness matrix from local data
%
%  local_data.mater = [elt# Diffusion Coeff Elt-thickness Capacitance Vx1 Vx2 ] For material type
%
%  local_data.coords = [ x1 x2 of node 1;
%                        x1 x2 of node 2;
%                        x1 x2 of node 3]
%
%  local_data.dofs   = [ dof1 dof2 dof3] Global dof referenced to local dofs
%
  Kl = zeros(3,3);
  Cl = zeros(3,3);
  Ml = zeros(3,3);
  D  = zeros(2,2);
  A  = zeros(2,3);
%
%  Constitutive matrix - Darcy's Law, Fick's Law, Fourier's Law, Ohm's Law
%
  diffusioncoef= local_data.mater(1,2);
  thickness    = local_data.mater(1,3);
  capacitance  = local_data.mater(1,4);
  v = [local_data.mater(1,5); local_data.mater(1,6) ];
%-------------------------------- Evalaute constitutive matrix
             D = diffusioncoef * [1 0; 0 1];
%-------------------------------- Evaluate coefs and determinant for element area
    b = local_data.coords(2,1)*local_data.coords(3,2) - local_data.coords(3,1)*local_data.coords(2,2);
    b21 = local_data.coords(2,2) - local_data.coords(3,2);
    b31 = local_data.coords(3,1) - local_data.coords(2,1);
    d2  = local_data.coords(1,1)*b21 + local_data.coords(1,2)*b31 + b;
    area = d2/2;
%-------------------------------- Evaluate derivatives of shape functions
A = (1/d2) * [ b21  (local_data.coords(3,2)-local_data.coords(1,2))  (local_data.coords(1,2)-local_data.coords(2,2));
               b31  (local_data.coords(1,1)-local_data.coords(3,1))  (local_data.coords(2,1)-local_data.coords(1,1))];
%-------------------------------- Evaluate second order matrix (diffusion)
    secondorder = zeros(3,3); 
    secondorder = A'*(D*A)*area*thickness
%-------------------------------- Evaluate first order matrix (advection)
    factor = ones(3,1)/3
    firstorder = zeros(3,3);  
    firstorder = factor*(v'*A)*area*thickness
%-------------------------------- Evalaute conductance matrix
Kl = secondorder + firstorder;
%-------------------------------- Evalaute consistent mass (storage) matrix
Cl = (area*thickness*capacitance/3) * [ 1 0 0; 0 1 0; 0 0 1];

         
         
